@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
+ * Copyright (C) 2001-2002 Mikael Hallendal <micke@imendio.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * Author: Mikael Hallendal <micke@codefactory.se>
+ * Author: Mikael Hallendal <micke@imendio.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -290,7 +290,6 @@ index_complete_idle (YelpViewIndex *view)
 {
 	YelpViewIndexPriv *priv;
 	const gchar       *text;
-	gchar		  *tmp_text;
 	gchar             *completed = NULL;
 	GList             *list;
 	gint               text_length;
@@ -300,12 +299,10 @@ index_complete_idle (YelpViewIndex *view)
 	priv = view->priv;
 	
 	text = gtk_entry_get_text (GTK_ENTRY (priv->entry));
-	tmp_text = g_strdup (text);
 
 	list = g_completion_complete (priv->completion, 
-				      tmp_text,
+				      (gchar *)text,
 				      &completed);
-	g_free (tmp_text);
 
 	if (completed) {
 		text_length = strlen (text);
